
.. .. image:: https://readthedocs.org/projects/aws_arns/badge/?version=latest
    :target: https://aws_arns.readthedocs.io/index.html
    :alt: Documentation Status

.. image:: https://github.com/MacHu-GWU/aws_arns-project/workflows/CI/badge.svg
    :target: https://github.com/MacHu-GWU/aws_arns-project/actions?query=workflow:CI

.. image:: https://codecov.io/gh/MacHu-GWU/aws_arns-project/branch/main/graph/badge.svg
    :target: https://codecov.io/gh/MacHu-GWU/aws_arns-project

.. image:: https://img.shields.io/pypi/v/aws_arns.svg
    :target: https://pypi.python.org/pypi/aws_arns

.. image:: https://img.shields.io/pypi/l/aws_arns.svg
    :target: https://pypi.python.org/pypi/aws_arns

.. image:: https://img.shields.io/pypi/pyversions/aws_arns.svg
    :target: https://pypi.python.org/pypi/aws_arns

.. image:: https://img.shields.io/badge/Release_History!--None.svg?style=social
    :target: https://github.com/MacHu-GWU/aws_arns-project/blob/main/release-history.rst

.. image:: https://img.shields.io/badge/STAR_Me_on_GitHub!--None.svg?style=social
    :target: https://github.com/MacHu-GWU/aws_arns-project

------

.. .. image:: https://img.shields.io/badge/Link-Document-blue.svg
    :target: https://aws_arns.readthedocs.io/index.html

.. .. image:: https://img.shields.io/badge/Link-API-blue.svg
    :target: https://aws_arns.readthedocs.io/py-modindex.html

.. .. image:: https://img.shields.io/badge/Link-Source_Code-blue.svg
    :target: https://aws_arns.readthedocs.io/py-modindex.html

.. image:: https://img.shields.io/badge/Link-Install-blue.svg
    :target: `install`_

.. image:: https://img.shields.io/badge/Link-GitHub-blue.svg
    :target: https://github.com/MacHu-GWU/aws_arns-project

.. image:: https://img.shields.io/badge/Link-Submit_Issue-blue.svg
    :target: https://github.com/MacHu-GWU/aws_arns-project/issues

.. image:: https://img.shields.io/badge/Link-Request_Feature-blue.svg
    :target: https://github.com/MacHu-GWU/aws_arns-project/issues

.. image:: https://img.shields.io/badge/Link-Download-blue.svg
    :target: https://pypi.org/pypi/aws_arns#files


☁️ Welcome to ``aws_arns`` Documentation
==============================================================================
Amazon Resource Names (ARNs) Python library. It parses / constructs ARN in Python, and provide more human intuitive interface to access AWS Resource attributes like aws service name, aws account id, aws region, resource type, resource id, resource name, short name, long name, etc ...

See `usage examples <https://github.com/MacHu-GWU/aws_arns-project/blob/main/examples.ipynb>`_.


.. _install:

Install
------------------------------------------------------------------------------

``aws_arns`` is released on PyPI, so all you need is:

.. code-block:: console

    $ pip install aws_arns

To upgrade to latest version:

.. code-block:: console

    $ pip install --upgrade aws_arns